
/* Chrysalide - Outil d'analyse de fichiers binaires
 * elf.h - prototypes pour le support du format ELF
 *
 * Copyright (C) 2009-2017 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef _FORMAT_ELF_ELF_H
#define _FORMAT_ELF_ELF_H


#include <glib-object.h>
#include <stdbool.h>
#include <sys/types.h>


#include "elf_def.h"
#include "../../core/formats.h"



#define G_TYPE_ELF_FORMAT               g_elf_format_get_type()
#define G_ELF_FORMAT(obj)               (G_TYPE_CHECK_INSTANCE_CAST((obj), g_elf_format_get_type(), GElfFormat))
#define G_IS_ELF_FORMAT(obj)            (G_TYPE_CHECK_INSTANCE_TYPE((obj), g_elf_format_get_type()))
#define G_ELF_FORMAT_GET_IFACE(inst)    (G_TYPE_INSTANCE_GET_INTERFACE((inst), g_elf_format_get_type(), GElfFormatIface))
#define G_ELF_FORMAT_GET_CLASS(obj)     (G_TYPE_INSTANCE_GET_CLASS((obj), G_TYPE_ELF_FORMAT, GElfFormatClass))


/* Format d'exécutable ELF (instance) */
typedef struct _GElfFormat GElfFormat;

/* Format d'exécutable ELF (classe) */
typedef struct _GElfFormatClass GElfFormatClass;


/* Indique si le format peut être pris en charge ici. */
FormatMatchStatus elf_is_matching(GBinContent *, GExeFormat *, void *, char **);

/* Indique le type défini pour un format d'exécutable ELF. */
GType g_elf_format_get_type(void);

/* Prend en charge un nouveau format ELF. */
GBinFormat *g_elf_format_new(GBinContent *, GExeFormat *, GtkStatusStack *);

/* Présente l'en-tête ELF du format chargé. */
const elf_header *g_elf_format_get_header(const GElfFormat *);



#endif  /* _FORMAT_ELF_ELF_H */
